@@ -224,7 +224,11 @@ int deep_opt;
         ipnt += 8;
     }
     else {
+#ifdef ultrix
+        set_733((char*)Rock + ipnt, (lstatbuf->st_rdev >> 16) >> 16);
+#else
         set_733((char*)Rock + ipnt, lstatbuf->st_rdev >> 32);
+#endif
         ipnt += 8;
         set_733((char*)Rock + ipnt, lstatbuf->st_rdev);
         ipnt += 8;
@@ -425,8 +429,9 @@ int deep_opt;
       else {
 	int blocksize;
 	blocksize = (header[3] << 8) | header[2];
-	file_size = (header[7] << 24) | (header[6] << 16) | 
-	  (header[5] << 8) | header[4];
+	file_size = ((unsigned int)header[7] << 24) | 
+		    ((unsigned int)header[6] << 16) | 
+		    ((unsigned int)header[5] << 8)  | header[4];
 #if 0
 	fprintf(stderr,"Blocksize = %d %d\n", blocksize, file_size);
 #endif
@@ -477,7 +482,7 @@ int deep_opt;
   if(recstart)
     set_733((char*)Rock + recstart - 8, ipnt - recstart);
 
-  s_entry->rr_attributes = (char *) e_malloc(ipnt);
+  s_entry->rr_attributes = (unsigned char *) e_malloc(ipnt);
   s_entry->total_rr_attr_size = ipnt;
   s_entry->rr_attr_size = (mainrec ? mainrec : ipnt);
   memcpy(s_entry->rr_attributes, Rock, ipnt);
