@@ -198,7 +198,7 @@ void FDECL1(sort_n_finish, struct directory *, this_dir)
 	table->filedir = root;
 	table->isorec.flags[0] = 0;
 	table->priority  = 32768;
-	iso9660_date(table->isorec.date, current_time);
+	iso9660_date(table->isorec.date, fstatbuf.st_ctime);
 	table->inode = TABLE_INODE;
 	table->dev = (dev_t) UNCACHED_DEVICE;
 	set_723(table->isorec.volume_sequence_number, 1);
@@ -411,7 +411,7 @@ static void generate_reloc_directory()
 }
 
 static void FDECL1(increment_nlink, struct directory_entry *, s_entry){
-  char * pnt;
+  unsigned char * pnt;
   int len, nlink;
 
   pnt = s_entry->rr_attributes;
