@@ -100,9 +100,11 @@ void FDECL2(set_733, char *, pnt, unsigned int, i){
 
 static FDECL4(xfwrite, void *, buffer, int, count, int, size, FILE *, file)
 {
-  if (!fwrite(buffer, count, size, file) != size) return;
-  fprintf(stderr,"cannot write raw file\n"); 
-  exit(1);
+  while(count) {
+	int got=fwrite(buffer,size,count,file);
+	if(got<=0) fprintf(stderr,"cannot fwrite %d*%d\n",size,count),exit(1);
+	count-=got,*(char**)&buffer+=size*got;
+  }
 }
 
 struct deferred_write{
@@ -507,6 +509,9 @@ void FDECL2(generate_one_directory, struct directory *, dpnt, FILE *, outfile){
 
     s_entry_d = s_entry;
     s_entry = s_entry->next;
+
+    if (s_entry_d->rr_attributes) free(s_entry_d->rr_attributes);
+    free (s_entry_d->name);
     free (s_entry_d);
   };
   sort_dir = NULL;
